@@ -9,7 +9,7 @@ class FineractException(Exception):
         Exception.__init__(self)
         self.__status = status
         self.__data = data
-        self.args = [status, data]
+        self.args = (status, data)
 
     @property
     def status(self):
