@@ -4,5 +4,7 @@ from .document import Document
 from .hook import Hook
 from .loan import Loan
 from .report import Report
+from .note import Note
+from .savings import Savings
 
-__all__ = ['Client', 'DataTable', 'Document', 'Report', 'Hook', 'Loan']
+__all__ = ['Client', 'DataTable', 'Document', 'Report', 'Hook', 'Loan', 'Note', 'Savings']
